# remirepo spec file for php-pecl-opentelemetry
#
# SPDX-FileCopyrightText:  Copyright 2023-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-pecl-opentelemetry}

%bcond_without     tests

%global pie_vend   open-telemetry
%global pie_proj   ext-opentelemetry
%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  opentelemetry
%global ini_name   40-%{pecl_name}.ini

%global upstream_version 1.1.3
#global upstream_prever  beta3
%global upstream_lower   %(echo %{upstream_prever} | tr '[:upper:]' '[:lower:]')
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

Summary:        OpenTelemetry auto-instrumentation support extension
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_lower}}
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        Apache-2.0
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?dtsprefix}gcc-c++
BuildRequires:  %{?scl_prefix}php-devel >= 8.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}                 = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})           = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa}   = %{version}
Provides:       %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj}) = %{version}
Provides:       %{?scl_prefix}php-%{pie_vend}-%{pie_proj}      = %{version}


%description
OpenTelemetry auto-instrumentation extension.

This is a PHP extension for OpenTelemetry, to enable auto-instrumentation.
It is based on zend_observer and requires php8+

The extension allows creating pre and post hook functions to arbitrary PHP
functions and methods, which allows those methods to be wrapped with telemetry.


Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
: Sanity check, really often broken
extver=$(sed -n '/#define PHP_OPENTELEMETRY_VERSION /{s/.* "//;s/".*$//;p}' php_%{pecl_name}.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{summary}
extension=%{pecl_name}.so

; Configuration
;opentelemetry.conflicts = 'blackfire'
;opentelemetry.validate_hook_functions = On
;opentelemetry.allow_stack_extension = Off
;opentelemetry.attr_hooks_enabled = Off
;opentelemetry.display_warnings = Off
;opentelemetry.attr_pre_handler_function =OpenTelemetry\API\Instrumentation\WithSpanHandler::pre
;opentelemetry.attr_post_handler_function = OpenTelemetry\API\Instrumentation\WithSpanHandler::post
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
sed -e 's/INSTALL_ROOT/DESTDIR/' -i build/Makefile.global

cd ../NTS
%configure \
    --enable-opentelemetry \
    --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --enable-opentelemetry \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'
%endif


%files
%license %{sources}/LICENSE*

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Wed May 14 2025 Remi Collet <remi@remirepo.net> - 1.1.3-1
- update to 1.1.3

* Thu Jan 23 2025 Remi Collet <remi@remirepo.net> - 1.1.2-1
- update to 1.1.2

* Tue Jan 21 2025 Remi Collet <remi@remirepo.net> - 1.1.1-1
- update to 1.1.1
- re-license spec file to CECILL-2.1

* Thu Oct  3 2024 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0

* Tue Sep 10 2024 Remi Collet <remi@remirepo.net> - 1.1.0~beta3-1
- update to 1.1.0beta3

* Wed Sep  4 2024 Remi Collet <remi@remirepo.net> - 1.1.0~beta2-1
- update to 1.1.0beta2
- open https://github.com/open-telemetry/opentelemetry-php/issues/1376 PHP 8.4 compatibility

* Sat May  4 2024 Remi Collet <remi@remirepo.net> - 1.0.3-1
- update to 1.0.3

* Thu May  2 2024 Remi Collet <remi@remirepo.net> - 1.0.3~beta1-1
- update to 1.0.3beta1

* Thu Apr 11 2024 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Tue Mar 26 2024 Remi Collet <remi@remirepo.net> - 1.0.2~beta3-1
- update to 1.0.2beta3

* Tue Mar 19 2024 Remi Collet <remi@remirepo.net> - 1.0.2~beta2-1
- update to 1.0.2beta2

* Tue Feb  6 2024 Remi Collet <remi@remirepo.net> - 1.0.2~beta1-1
- update to 1.0.2beta1

* Mon Feb  5 2024 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Tue Jan 30 2024 Remi Collet <remi@remirepo.net> - 1.0.1~beta2-1
- update to 1.0.1beta2

* Thu Jan 25 2024 Remi Collet <remi@remirepo.net> - 1.0.1~beta1-1
- update to 1.0.1beta1

* Wed Oct 25 2023 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0

* Fri Oct 20 2023 Remi Collet <remi@remirepo.net> - 1.0.0~RC3-1
- update to 1.0.0RC3

* Tue Oct 17 2023 Remi Collet <remi@remirepo.net> - 1.0.0~RC2-1
- update to 1.0.0RC2

* Tue Sep 12 2023 Remi Collet <remi@remirepo.net> - 1.0.0~RC1-1
- update to 1.0.0RC1

* Tue Sep  5 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta7-1
- update to 1.0.0beta7

* Wed Jun 14 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta6-1
- update to 1.0.0beta6

* Wed May 10 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta5-1
- update to 1.0.0beta5

* Wed Apr 19 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta4-1
- update to 1.0.0beta4

* Sat Apr  1 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta3-1
- update to 1.0.0beta3
- extension renamed from otel_instrumentation to opentelemetry

* Thu Mar 30 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta2-1
- initial package, version 1.0.0beta2
- open https://github.com/open-telemetry/opentelemetry-php-instrumentation/issues/45
  missing license file and tests
- open https://github.com/open-telemetry/opentelemetry-php-instrumentation/issues/46
  missing extension version
